@@ -15,7 +15,7 @@ from matplotlib.collections import PathCollection, QuadMesh
 from matplotlib.text import Annotation
 from numpy import array, allclose, argmin, argmax, where, abs as np_abs
 from SciDataTool.Functions.is_axes_in_order import is_axes_in_order
-from SciDataTool.Functions.Plot import TEXT_BOX
+from SciDataTool.Functions.Plot import TEXT_BOX, fft_dict
 from SciDataTool.Classes.Norm_ref import Norm_ref
 
 
@@ -79,6 +79,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         save_path="",
         logger=None,
         path_to_image=None,
+        text_box=None,
     ):
         """Initialize the UI according to the input given by the user
 
@@ -126,6 +127,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         self.plot_arg_dict = plot_arg_dict
         self.data = data
         self.data_orig = data
+        self.text_box = text_box
 
         # Initializing the figure inside the UI
         (self.fig, self.ax, _, _) = init_fig()
@@ -215,7 +217,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
 
         """
         if text_box is None:
-            text_box = TEXT_BOX
+            if self.text_box is None:
+                text_box = TEXT_BOX
+            else:
+                text_box = self.text_box
         # Set plot layout
         self.canvas = FigureCanvas(fig)
         if self.toolbar is None:
@@ -471,7 +476,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
 
             # Offset for the label
             x_min, x_max = self.ax.get_xlim()
-            dx = (x_max - x_min) / 50
+            dx = (x_max - x_min) / 20
             if X is not None and Y is not None:
                 if isinstance(X, str):
                     X = ind
@@ -665,7 +670,19 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                             + " "
                             + self.data.get_axes(axis_cont)[0].values[index]
                         )
-                    self.data.plot_2D_Data(
+                    if "y_min" in plot_arg_dict_2D:
+                        del plot_arg_dict_2D["y_min"]
+                    if "y_max" in plot_arg_dict_2D:
+                        del plot_arg_dict_2D["y_max"]
+                    if (
+                        "data_list" in plot_arg_dict_2D
+                        and "wavenumber" in axes_selected[0]
+                    ):
+                        data = plot_arg_dict_2D["data_list"][0]
+                        del plot_arg_dict_2D["data_list"]
+                    else:
+                        data = self.data
+                    data.plot_2D_Data(
                         *[*axes_selected, *data_selection],
                         **plot_arg_dict_2D,
                         unit=output_range["unit"],
@@ -694,6 +711,12 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                                         + "{"
                                         + axis_selected.split("{")[1]
                                     )
+                if "y_min" in plot_arg_dict_3D:
+                    if "wavenumber" not in axes_selected[1]:
+                        del plot_arg_dict_3D["y_min"]
+                if "y_max" in plot_arg_dict_3D:
+                    if "wavenumber" not in axes_selected[1]:
+                        del plot_arg_dict_3D["y_max"]
                 if output_range["min"] is not None:
                     plot_arg_dict_3D["z_min"] = output_range["min"]
                 if output_range["max"] is not None:
