@@ -155,15 +155,6 @@ def plot_2D_Data(
     # Fix axes order
     arg_list_along = fix_axes_order([axis.name for axis in self.get_axes()], arg_list)
 
-    # If fft axes in data but axis not required, request ifft axis
-    for axis in self.get_axes():
-        if (
-            axis.name in ifft_dict
-            and axis.name not in axes_names
-            and ifft_dict[axis.name] not in axes_names
-        ):
-            arg_list_along.append(ifft_dict[axis.name] + "[0]")
-
     # In case of 1D fft, keep only positive wavenumbers
     for i, arg in enumerate(arg_list_along):
         if "wavenumber" in arg and "=" not in arg and "[" not in arg:
@@ -798,39 +789,10 @@ def plot_2D_Data(
         if annotations is not None:
             try:
                 annot = list()
-                axis_along = self.get_axes(annotations[0])[0]
-                axis_op = self.get_axes(annotations[1])[0]
-                operation = annotations[2]
-                arg_list_new = []
-                if self.unit == "W":
-                    op = "=sum"
-                else:
-                    op = "=rss"
-                for axis in self.get_axes():
-                    if axis.name not in [axis_along.name, axis_op.name]:
-                        arg_list_new.append(axis.name + op)
-                    else:
-                        arg_list_new.append(axis.name)
-                data2 = self.get_data_along(*arg_list_new, unit=unit)
-                arg_list_new = []
-                for arg in arg_list_along:
-                    if axis_along.name in arg or axis_op.name in arg:
-                        if "[" in arg:
-                            arg_list_new.append(arg.split("[")[0])
-                        else:
-                            arg_list_new.append(
-                                arg.replace("=sum", "").replace("=rss", "")
-                            )
-                result = data2.get_magnitude_along(*arg_list_new)
-                for ii in range(len(result[annotations[0]])):
-                    if operation == "max":
+                for ii in range(len(self.get_axes(annotations[0])[0].get_values())):
+                    if annotations[2] == "max":
                         index = argmax(take(result[self.symbol], ii, axis=0))
-                        annot.append(
-                            "main "
-                            + annotations[1].rstrip("s")
-                            + ": "
-                            + axis_op.get_values()[index]
-                        )
+                        annot.append("main " + annotations[1].rstrip("s") + ": ")
                 # Keep only requested indices
                 annot = array(annot)[
                     axes_list[
